@@ -1,4 +1,4 @@
-// $Id: BackupDlg.cpp,v 1.22.4.1 2004/04/12 17:04:25 binner Exp $
+// $Id: BackupDlg.cpp,v 1.24 2004/04/12 16:59:22 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -28,7 +28,8 @@
 #include <qdir.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbutton.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include <kapplication.h>
 #include <kprocess.h>
@@ -80,7 +81,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
 
     resize( 515, 300 );
 
-    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g"
+    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g" 
        so we'll provide that plus some space beyond it. */
     // const int labelWidth = 96;
     const int labelWidth = 110;
@@ -278,7 +279,7 @@ void BackupDlg::show()
         KMessageBox::information(this, i18n("No files to back up. Aborting."));
         slotAbort();
         return;
-    }
+    }          
 
     connect( _proc, SIGNAL( processExited( KProcess* ) ), this, SLOT( slotProcessExited( KProcess* ) ) );
     connect( _proc, SIGNAL( receivedStdout( KProcess*, char*, int ) ), this, SLOT( slotStdout( KProcess*, char*, int ) ) );
