@@ -1,5 +1,6 @@
 /*
  *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
  *  Maintained by Adriaan de Groot <groot@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
@@ -20,23 +21,17 @@
 #ifndef _KU_GLOBALS_H_
 #define _KU_GLOBALS_H_
 
-#define _KU_VERSION "1.0"
+#define _KU_VERSION "2.0"
 
 #include <config.h>
 #ifdef HAVE_PATHS_H
 #include <paths.h>
 #endif
 #include <kconfig.h>
-#include "kerror.h"
-
-#ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
-#endif
-
-extern int is_quota;
-extern int is_shadow;
+#include "kuserprefs.h"
 
 #define KU_BACKUP_EXT ".bak"
+#define KU_CREATE_EXT ".new"
 
 #ifdef HAVE_PATHS_H
   #define SHELL_FILE _PATH_SHELLS
@@ -52,40 +47,20 @@ extern int is_shadow;
   #define PASSWORD_FILE _PATH_MASTERPASSWD
   #define PASSWORD_FILE_MASK S_IRUSR | S_IWUSR
   #define PWMKDB _PATH_PWD_MKDB" -p "PASSWORD_FILE
-  #define GROUP_FILE "/etc/group"
-  #define GROUP_FILE_MASK S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH
   #define SKELDIR "/usr/share/skel"
   #define SKEL_FILE_PREFIX "dot"
+  #define CRONTAB_DIR "/var/cron/tabs"
 #else
   #define PASSWORD_FILE "/etc/passwd"
   #define PASSWORD_FILE_MASK S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH
-  #define GROUP_FILE "/etc/group"
-  #define GROUP_FILE_MASK S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH
   #define PWMKDB "cd /var/yp; make 2>&1 >> /var/log/kuser"
   #define GRMKDB "cd /var/yp; make 2>&1 >> /var/log/kuser"
   #define SKELDIR "/etc/skel"
   #define SKEL_FILE_PREFIX ""
+  #define CRONTAB_DIR "/var/spool/cron"
 #endif
 
-extern KConfig *config;
-extern KError *err;
-
-#ifdef HAVE_SHADOW
-#define SHADOW_FILE "/etc/shadow"
-#define SHADOW_FILE_MASK S_IRUSR | S_IWUSR
-#endif
-
-#ifdef AIX
-extern "C" int getuid(void);
-extern "C" int unlink(const char *);
-#endif
-
-#define KU_HOMEDIR_PERM 0755
-#define KU_KDEDIRS_PERM 0700													
-#define KU_MAILBOX_PERM 0660
-
-#define KU_MAILBOX_GID 0
-
-#define KU_FIRST_USER 1001
+#define GROUP_FILE "/etc/group"
+#define GROUP_FILE_MASK S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH
 
 #endif // _KU_GLOBALS_H_
