@@ -23,6 +23,9 @@
 ** MA 02111-1307, USA.
 */
 
+#ifndef _KCONTROL_H_
+#define _KCONTROL_H_
+
 /*
 ** Bug reports and questions can be sent to kde-devel@kde.org
 */
@@ -46,3 +49,6 @@ public slots:
 private:
 	MainWidget	*m;
 };
+
+#endif
+
